@@ -1,9 +1,10 @@
-# This is a module for time this will also be implemented in standalone
+import sys, os
+sys.path.append("c:/users/" + os.getlogin() + "/scoop/apps/python/current/lib/site-packages/dataextract")
+
 try:
   import datetime
   import time
   import string
-  import os
 except ImportError:
   print("Error: Missing module(s) please install the following module(s): random, time, hashlib, string")
 
